gammaALPs
=========

.. image:: https://img.shields.io/pypi/v/gammaALPs
    :target: https://pypi.org/project/gammaALPs/
    :alt: Latest Release

.. image:: https://img.shields.io/travis/me-manu/gammaALPs
    :target: https://img.shields.io/travis/me-manu/gammaALPs

.. image:: https://readthedocs.org/projects/gammaalps/badge/?version=latest
    :target: https://gammaalps.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. image:: https://img.shields.io/codecov/c/gh/me-manu/gammaALPs
    :target: https://codecov.io/gh/me-manu/gammaALPs/
    :alt: Code Coverage

.. image:: https://img.shields.io/github/license/me-manu/gammaALPs
    :target: https://github.com/me-manu/gammaALPs
    :alt: License
    
.. image:: https://img.shields.io/github/issues/me-manu/gammaALPs
    :target: https://github.com/me-manu/gammaALPs/issues
    :alt: Issues

.. image:: https://zenodo.org/badge/96319590.svg
   :target: https://zenodo.org/badge/latestdoi/96319590
   :alt: DOI

.. image:: https://img.shields.io/badge/ascl-2109.001-blue.svg?colorB=262255
   :target: https://ascl.net/2109.001
   :alt: ascl:2109.001

Python packages to calculate the conversion probability between photons and axions / axion-like particles in
various astrophysical magnetic fields.

For the documentation and full installation instructions see: https://gammaalps.readthedocs.io/en/latest

Prerequisites
-------------

Python 3.6 or higher and the following packages
    - numpy 
    - scipy
    - astropy
    - ebltable
    - numba

Installation
------------

You can use pip to install the package:: 

    pip install gammaALPs 

Check out full installation instructions at: https://gammaalps.readthedocs.io/en/latest/installation.html

License
-------
This project is licensed under a 3-clause BSD style license - see the
``LICENSE`` file.
